# Edit this configuration file to define what should be installed on
# your system.  Help is available in the configuration.nix(5) man page
# and in the NixOS manual (accessible by running ‘nixos-help’).

{ config, pkgs, ... }:

{
  imports =
    [ # Include the results of the hardware scan.
      ./hardware-configuration.nix
    ];

  # Use the GRUB 2 boot loader.
  boot.loader.grub.enable = true;
  boot.loader.grub.version = 2;
  # boot.loader.grub.efiSupport = true;
  # boot.loader.grub.efiInstallAsRemovable = true;
  # boot.loader.efi.efiSysMountPoint = "/boot/efi";
  # Define on which hard drive you want to install Grub.
  boot.loader.grub.device = "/dev/sda"; # or "nodev" for efi only

  networking.hostName = "vpn7";
  networking.domain = "cccgoe.de";

  # The global useDHCP flag is deprecated, therefore explicitly set to false here.
  # Per-interface useDHCP will be mandatory in the future, so this generated config
  # replicates the default behaviour.
  networking.useDHCP = false;
  networking.useNetworkd = true;

  systemd.network = {
    links."10-eth0" = {
      matchConfig.MACAddress = "f6:ac:c8:5c:f5:ce";
      linkConfig.Name = "eth0";
    };
    networks."10-eth0" = {
      matchConfig = {
        Name = "eth0";
      };
      addresses = [
        {
          addressConfig = {
            Address = "88.99.250.3/32";
            Peer = "88.99.250.30/32";
          };
        }
      ];
      gateway = [ "88.99.250.30"];
      dns = [ "5.1.66.255" "185.150.99.255" "2001:678:e68:f000::" "2001:678:ed0:f000::" ];
    };
  };

  # This value determines the NixOS release from which the default
  # settings for stateful data, like file locations and database versions
  # on your system were taken. It‘s perfectly fine and recommended to leave
  # this value at the release version of the first install of this system.
  # Before changing this value read the documentation for this option
  # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
  system.stateVersion = "21.11"; # Did you read the comment?

}

